@@ -5,9 +5,6 @@
 --        things without them overlapping
 module HLint.Test where
 
-import "hint" HLint.Builtin.All
-
-
 error = Prelude.readFile ==> bad
 
 error = (x :: Int) ==> (x :: Int32)
@@ -105,10 +102,6 @@ zip [1..length x] x -- zipFrom 1 x
 {-# ANN module "HLint: ignore Unused LANGUAGE pragma" #-} \
 {-# LANGUAGE RecordWildCards #-} -- @Ignore ???
 
-{-# ANN module "HLint: ignore Use import/export shortcut" #-} \
-module ABCD(module A, module B, module C) where \
-import A; import B; import C -- @Ignore ???
-
 {-# ANN lam "HLint: ignore Redundant lambda" #-} \
 lam = \x -> x x x -- @Ignore ???
 
