@@ -3,7 +3,7 @@
 module HSE.Match(
     View(..), Named(..),
     (~=), isSym,
-    App2(App2), PVar_(PVar_), Var_(Var_), PApp_(PApp_)
+    App2(App2), LamConst1(LamConst1), PVar_(PVar_), Var_(Var_), PApp_(PApp_)
     ) where
 
 import Data.Char
@@ -29,6 +29,13 @@ instance View Exp_ App1 where
     view (fromParen -> App _ f x) = App1 f x
     view _ = NoApp1
 
+-- \_ -> body
+data LamConst1 = NoLamConst1 | LamConst1 Exp_ deriving Show
+
+instance View Exp_ LamConst1 where
+    view (fromParen -> Lambda _ [PWildCard _] x) = LamConst1 x
+    view _ = NoLamConst1
+
 data PApp_ = NoPApp_ | PApp_ String [Pat_]
 
 instance View Pat_ PApp_ where
