@@ -1,4 +1,4 @@
-{-# LANGUAGE FlexibleContexts, ViewPatterns #-}
+{-# LANGUAGE FlexibleContexts, ViewPatterns, TupleSections #-}
 
 module HSE.Util(module HSE.Util, def) where
 
@@ -85,9 +85,6 @@ fromTyBang :: Type s -> Type s
 fromTyBang (TyBang _ _ _ x) = x
 fromTyBang x = x
 
-fromDeriving :: Deriving s -> [InstRule s]
-fromDeriving (Deriving _ _ x) = x
-
 -- is* :: Exp_ -> Bool
 -- is* :: Decl_ -> Bool
 isVar Var{} = True; isVar _ = False
@@ -121,6 +118,8 @@ isTyBang TyBang{} = True; isTyBang _ = False
 isLCase LCase{} = True; isLCase _ = False
 isTupleSection TupleSection{} = True; isTupleSection _ = False
 isString String{} = True; isString _ = False
+isRecUpdate RecUpdate{} = True; isRecUpdate _ = False
+isRecConstr RecConstr{} = True; isRecConstr _ = False
 
 isSection LeftSection{} = True
 isSection RightSection{} = True
@@ -208,7 +207,7 @@ transformBracketOld :: (Exp_ -> Maybe Exp_) -> Exp_ -> Exp_
 transformBracketOld op = snd . g
     where
         g = f . descendBracketOld g
-        f x = maybe (False,x) ((,) True) (op x)
+        f x = maybe (False,x) (True,) (op x)
 
 -- | Descend, and if something changes then add/remove brackets appropriately
 descendBracketOld :: (Exp_ -> (Bool, Exp_)) -> Exp_ -> Exp_
@@ -235,6 +234,8 @@ isKindHash :: Type_ -> Bool
 isKindHash (TyParen _ x) = isKindHash x
 isKindHash (TyApp _ x _) = isKindHash x
 isKindHash (TyCon _ (fromQual -> Just (Ident _ s))) = "#" `isSuffixOf`  s
+isKindHash (TyTuple _ Unboxed _) = True
+isKindHash TyUnboxedSum{} = True
 isKindHash _ = False
 
 
