@@ -16,7 +16,7 @@
 data Yes = Foo | Bar'Test -- data Yes = Foo | BarTest
 data Yes = Bar | Test_Bar -- data Yes = Bar | TestBar
 data No = a :::: b
-data Yes = Foo {bar_cap :: Int} -- data Yes = Foo{barCap :: Int}
+data Yes = Foo {bar_cap :: Int}
 data No = FOO | BarBAR | BarBBar
 yes_foo = yes_foo + yes_foo -- yesFoo = ...
 no = 1 where yes_foo = 2
@@ -38,7 +38,7 @@ runMutator# = 1
 module Hint.Naming(namingHint) where
 
 import Hint.Type
-import Data.List
+import Data.List.Extra
 import Data.Data
 import Data.Char
 import Data.Maybe
@@ -46,11 +46,11 @@ import qualified Data.Set as Set
 
 
 namingHint :: DeclHint
-namingHint _ modu = naming $ Set.fromList [x | Ident _ x <- universeS modu]
+namingHint _ modu = naming $ Set.fromList $ concatMap getNames $ moduleDecls modu
 
 naming :: Set.Set String -> Decl_ -> [Idea]
 naming seen x = [suggestN "Use camelCase" x2 (replaceNames res x2) | not $ null res]
-    where res = [(n,y) | n <- nub $ getNames x, Just y <- [suggestName n], not $ y `Set.member` seen]
+    where res = [(n,y) | n <- nubOrd $ getNames x, Just y <- [suggestName n], not $ y `Set.member` seen]
           x2 = shorten x
 
 
@@ -81,13 +81,13 @@ getNames x = case x of
 
         f (ConDecl _ x _) = [x]
         f (InfixConDecl _ _ x _) = [x]
-        f (RecDecl _ x ys) = x : concat [y | FieldDecl _ y _ <- ys]
+        f (RecDecl _ x _) = [x]
 
 
 suggestName :: String -> Maybe String
 suggestName x
     | isSym x || good || not (any isLower x) || any isDigit x ||
-        any (`isPrefixOf` x) ["prop_","case_","test_"] = Nothing
+        any (`isPrefixOf` x) ["prop_","case_","unit_","test_","spec_","scprop_","hprop_"] = Nothing
     | otherwise = Just $ f x
     where
         good = all isAlphaNum $ drp '_' $ drp '#' $ drp '\'' $ reverse $ drp '_' x
