@@ -2,6 +2,7 @@
 
 module Util(
     defaultExtensions,
+    forceList,
     gzip, universeParentBi,
     exitMessage, exitMessageImpure
     ) where
@@ -16,6 +17,13 @@ import Data.Generics.Uniplate.Operations
 import Language.Haskell.Exts.Extension
 
 
+---------------------------------------------------------------------
+-- CONTROL.DEEPSEQ
+
+forceList :: [a] -> [a]
+forceList xs = length xs `seq` xs
+
+
 ---------------------------------------------------------------------
 -- SYSTEM.IO
 
